SystemOrganization addCategory: #'SmallBlog-Model'!
SystemOrganization addCategory: #'SmallBlog-Model-Persistence'!
SystemOrganization addCategory: #'SmallBlog-RSS'!
SystemOrganization addCategory: #'SmallBlog-UI'!
SystemOrganization addCategory: #'SmallBlog-UI-Admin'!

!TimeStamp class methodsFor: '*smallblog' stamp: 'avi 2/29/2004 12:02'!
fromRfc822String: aString 
	| dateTimeString tokens dateString timeString date time |
	dateTimeString _ (aString includes: $,)
		ifTrue: [aString copyAfter: $,]
		ifFalse: [aString].
	tokens _ dateTimeString findTokens: ' '.
	dateString _ tokens first, ' ', tokens second, ' ', tokens third.
	timeString _ tokens fourth, ' ', tokens fifth.
	date _ Date readFrom: (ReadStream on: dateString).
	time _ Time readFrom: (ReadStream on: timeString).
	^ self date: date time: time! !

WAControllerMain subclass: #SLBlogMain
	instanceVariableNames: 'blog'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 23:32'!
displayRss
	| response |
	response _ WAGenericResponse new contentType: 'text/xml'.
	SLRssWriter writeBlog: blog stories: blog recentStories on: response stream withBaseUrl: self session application baseUrl asString, '/', blog name.
	self session returnResponse: response! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:19'!
feed: feedName
	feedName = 'recent.xml' ifTrue: [self displayRss].
	feedName = 'all.xml' ifTrue: [self displayAllRss].! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:23'!
day: dayString month: monthString year: yearString
	| date |
	date _ Date
			newDay: dayString asNumber
			monthNumber: monthString asNumber
			year: yearString asNumber.
	self call: (SLFrame new blog: blog; date: date)! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 22:19'!
chooseBlog
	^ self call: (SLBlogList withMessage: 'Choose a blog:')! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:23'!
story: idString
	| id |
	id _ UUID fromString: idString.
	self call: (SLFrame new blog: blog; story: (blog storyWithId: id))! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:31'!
default
	self call: (SLFrame new blog: blog)! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:26'!
blogNamed: aString
	^ SLBlogStore current blogNamed: aString! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:18'!
start: aRequest
	| url tokens |
	url _ aRequest url allButFirst: self session application basePath size.
	tokens _ url findTokens: '/'.
	blog _ tokens isEmpty
				ifTrue: [self chooseBlog]
				ifFalse: [tokens first = 'admin'
							ifTrue: [self configureBlog: aRequest]
							ifFalse: [self blogNamed: tokens first]].
	
	tokens size = 4 ifTrue:  [self day: tokens fourth month: tokens third year: tokens second].
	tokens size = 3 ifTrue: [tokens second = 'rss' ifTrue: [self feed: tokens third]].
	tokens size = 2 ifTrue: [self story: tokens second].
	self default.! !

!SLBlogMain methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 13:00'!
configureBlog: aRequest
	(WARenderLoop new root: (SLBlogCreation new)) start: aRequest! !

Object subclass: #SLBlogStore
	instanceVariableNames: ''
	classVariableNames: 'Current'
	poolDictionaries: ''
	category: 'SmallBlog-Model-Persistence'!

!SLBlogStore commentStamp: 'mas 10/23/2003 21:24' prior: 0!
Abstract superclass for implementing blog persistence.!

!SLBlogStore class methodsFor: 'startup and shutdown' stamp: 'mas 10/23/2003 23:40'!
startUp: resuming
	"Notify current store if we are just starting up the image."

	resuming ifFalse: [^self].
	Current ifNotNil: [Current class startUp].
! !

SLBlogStore subclass: #SLMemoryStore
	instanceVariableNames: 'blogs'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-Model-Persistence'!

!SLMemoryStore commentStamp: 'mas 10/23/2003 21:23' prior: 0!
I persist a set of blogs within the Squeak image. I am stored as part of the image at shutdown and restored as part of the image at startup.

Structure:
 blogs		Dictionary -- instances of SLBlog keyed by name
!

!SLMemoryStore methodsFor: 'initialize' stamp: 'mas 10/25/2003 09:08'!
initialize
	 blogs _ Dictionary new.! !

!SLMemoryStore methodsFor: 'private' stamp: 'mas 10/25/2003 09:08'!
blogs: aDictionary
	blogs _ aDictionary! !

!SLMemoryStore methodsFor: 'private' stamp: 'mas 10/25/2003 17:53'!
newBlogNamed: aString
	^ SLBlog name: aString! !

SLMemoryStore subclass: #SLRssStore
	instanceVariableNames: 'mutex directory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-Model-Persistence'!

!SLRssStore commentStamp: 'mas 10/23/2003 21:26' prior: 0!
I persist a set of blogs as RSS streams in disk files outside the image. I store to disk at image shutdown and restore from disk at image startup.

Structure:
 directory		FileDirectory -- location for storage of persistent data
 mutex			Semaphore -- for protecting critical sections of code
!

!SLRssStore methodsFor: 'objects from disk' stamp: 'mas 10/25/2003 09:12'!
restoreFrom: aFileDirectory
	"Restore blogs from RSS files in the specified directory."
	
	| files |
	mutex critical: [
		Cursor read showWhile: [
			files _ self directory 
				fileNamesMatching: self class rssFilePattern.
			files do: [:each |
 				self restoreBlogFromFileNamed: each]]].
! !

!SLRssStore class methodsFor: 'startup and shutdown' stamp: 'mas 10/23/2003 23:42'!
shutDown
	"Save blogs to RSS files when we are shutting down the image."

	Current ifNotNil: [Current store]! !

!SLRssStore class methodsFor: 'startup and shutdown' stamp: 'mas 10/23/2003 23:35'!
startUp
	"Restore blogs from files if we are just starting up the image."

	self restore.
! !

!SLRssStore methodsFor: 'private' stamp: 'mas 10/24/2003 02:32'!
store
	"Ensure that all my blogs are persistent."
	self directory assureExistence.
	self blogs do: [:each | self storeBlog: each].! !

!SLRssStore methodsFor: 'objects from disk' stamp: 'mas 10/25/2003 19:47'!
fileExistsForBlogNamed: aString
	^ directory fileExists: (self fileNameForBlogNamed: aString)! !

!SLRssStore class methodsFor: 'constants' stamp: 'mas 10/24/2003 02:20'!
rssFileExtension
	"The extension to be used for RSS files."

	^'.xml'! !

!SLRssStore methodsFor: 'objects from disk' stamp: 'avi 2/29/2004 12:04'!
storeBlog: anSLBlog
	"Ensure that all changes made to blog are now persistent."

	"Write object data as an RSS stream to a disk file."
	"We are careful not to overwrite existing data file until all data
	has been written successfully."

	| shortName stream tempName oldName |
	"Note that we don't want the tempName or oldName to end with
	the rssFileExtension or we will try to use them during restore."
	shortName _ anSLBlog name, self class rssFileExtension.
	tempName _ shortName, '.temp'.
	oldName _ shortName, '.old'.

	"mutex critical: ["
		Cursor write showWhile: [
			directory deleteFileNamed: tempName ifAbsent: [].
			stream _ CrLfFileStream 
				newFileNamed: (directory fullNameFor: tempName).
			SLRssWriter writeBlog: anSLBlog on: stream.
			stream close.

			"We really want the following operations to be atomic,
			but the Squeak file primitives to not currently support
			an atomic rename/move. So this is about the best we can do."

			directory deleteFileNamed: oldName ifAbsent: [].
			(directory fileExists: shortName)
				ifTrue: [directory rename: shortName toBe: oldName].
			directory rename: tempName toBe: shortName]"]".

! !

!SLRssStore methodsFor: 'initialize-release' stamp: 'mas 10/25/2003 09:14'!
initialize
	super initialize.
	mutex _ Semaphore forMutualExclusion.
	directory _ self class defaultDirectory.! !

!SLRssStore methodsFor: 'objects from disk' stamp: 'mas 10/25/2003 19:34'!
fileNameForBlogNamed: aString
	^ aString, self class rssFileExtension! !

!SLRssStore class methodsFor: 'constants' stamp: 'avi 10/25/2003 12:05'!
defaultDirectory
	^ (FileDirectory default directoryNamed: 'blogs') assureExistence; yourself! !

!SLRssStore class methodsFor: 'objects from disk' stamp: 'mas 10/23/2003 22:39'!
restoreFrom: aFileDirectory
	"Return a blog store reconstituted from the specified directory."

	^(aFileDirectory exists)
		ifTrue: [self new restoreFrom: aFileDirectory]
		ifFalse: [nil].! !

!SLRssStore methodsFor: 'objects from disk' stamp: 'mas 10/25/2003 19:34'!
restoreBlogNamed: aString
	self restoreBlogFromFileNamed: (self fileNameForBlogNamed: aString)! !

!SLRssStore methodsFor: 'accessing' stamp: 'mas 10/24/2003 02:22'!
directory
	^ directory! !

!SLRssStore methodsFor: 'objects from disk' stamp: 'mas 10/25/2003 19:52'!
blogNamed: aString
	"Answer existing blog if it exists, else read from file, else create one."

	(self blogs includesKey: aString) ifFalse: [
			(self fileExistsForBlogNamed: aString) ifTrue: [
				self restoreBlogNamed: aString]].
	^ self blogs at: aString ifAbsentPut: [self newBlogNamed: aString]! !

!SLRssStore class methodsFor: 'constants' stamp: 'mas 10/23/2003 23:15'!
rssFilePattern
	"The pattern to be used for matching RSS files."

	^'*', self rssFileExtension! !

!SLRssStore class methodsFor: 'objects from disk' stamp: 'mas 10/23/2003 22:38'!
restore
	"Restore all instances of SLRssStore from persistent storage."
	"Here we assume there is only one SLRssStore to be restored."

	self current: (self restoreFrom: self defaultDirectory).! !

!SLRssStore methodsFor: 'objects from disk' stamp: 'mas 10/25/2003 09:14'!
restoreBlogFromFileNamed: aString
	"Restore blog from RSS file with specified path."

	| stream name blog |
	name _ (directory localNameFor: aString) sansPeriodSuffix.
	stream _ directory readOnlyFileNamed: aString.
	blog _ SLRssReader readBlogNamed: name from: stream.
	blogs at: name put: blog.
! !

!SLMemoryStore methodsFor: 'objects from disk' stamp: 'mas 10/23/2003 21:07'!
blogNamed: aString
	"Answer existing blog if it exists, else create one."
	^ self blogs at: aString ifAbsentPut: [self newBlogNamed: aString]! !

!SLMemoryStore methodsFor: 'private' stamp: 'mas 10/25/2003 17:52'!
sampleBlogNamed: aString
	| story blog comment |
	blog _ SLBlog name: aString.
	story _ SLStory parent: blog.
	story title: 'First Post'.
	story text: 'YHBT. YHL. HAND.'.
	story post.
	story _ SLStory parent: blog.
	story title: 'Second Post'.
	story text: '!!'.
	story post.
	comment _ SLComment parent: story.
	comment text: '!!!!!!'.
	comment post.
	comment _ SLComment parent: story.
	comment text: '!!!!!!(*&@#$*^$%'.
	comment post.
	story _ SLStory parent: blog.
	story title: 'Old Post'.
	story text: 'Ye Hath Been Trolled...'.
	story instVarNamed: 'timeStamp' put: (TimeStamp current minusDays: 7).
	story post.	
	^ blog	! !

!SLMemoryStore class methodsFor: 'instance creation' stamp: 'mas 10/25/2003 09:08'!
new
	^ self basicNew initialize! !

!SLMemoryStore methodsFor: 'objects from disk' stamp: 'mas 10/23/2003 21:13'!
storeBlog: anSLBlog
	"Ensure that all changes made to blog are now persistent."

	"Nothing is required since I am saved persistently in the image."! !

!SLMemoryStore methodsFor: 'private' stamp: 'mas 10/25/2003 09:08'!
blogs
	^ blogs! !

!SLMemoryStore class methodsFor: 'instance creation' stamp: 'mas 10/24/2003 03:23'!
newFrom: anSLMemoryStore
	"Convert from some flavor of SLMemoryStore to another."

	^self new blogs: anSLMemoryStore blogs! !

!SLBlogStore class methodsFor: 'accessing' stamp: 'avi 10/25/2003 11:58'!
default
	^ SLRssStore new! !

!SLBlogStore methodsFor: 'objects from disk' stamp: 'mas 10/23/2003 21:13'!
storeBlog: anSLBlog
	"Ensure that all changes made to blog are now persistent."
	self subclassResponsibility! !

!SLBlogStore class methodsFor: 'class initialization' stamp: 'mas 10/23/2003 23:43'!
initialize
	Smalltalk addToStartUpList: self after: AutoStart.
	Smalltalk addToShutDownList: self! !

!SLBlogStore class methodsFor: 'startup and shutdown' stamp: 'mas 10/23/2003 23:40'!
shutDown: quitting
	"Notify current store if we are shutting down the image."

	quitting ifTrue: [Current ifNotNil: [Current class shutDown]]
! !

!SLBlogStore class methodsFor: 'startup and shutdown' stamp: 'mas 10/23/2003 23:39'!
startUp
	"Do what is necessary when we are starting up the image."
! !

!SLBlogStore class methodsFor: 'startup and shutdown' stamp: 'mas 10/23/2003 23:39'!
shutDown
	"Do what is necessary when we are shutting down the image."
! !

!SLBlogStore class methodsFor: 'accessing' stamp: 'avi 10/23/2003 17:20'!
current
	^ Current ifNil: [Current _ self default]! !

!SLBlogStore class methodsFor: 'accessing' stamp: 'avi 10/23/2003 17:20'!
current: aBlogStore
	Current _ aBlogStore! !

!SLBlogStore methodsFor: 'objects from disk' stamp: 'mas 10/23/2003 21:04'!
blogNamed: aString
	"Answer existing blog if it exists, else create one."
	self subclassResponsibility ! !

Object subclass: #SLBlog
	instanceVariableNames: 'name title description stories username passwordHash'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-Model'!

!SLBlog methodsFor: 'syndication-required elements' stamp: 'mas 10/24/2003 01:00'!
description
	"Phrase or sentence describing the channel."
	"Example: 
		The latest news from GoUpstate.com,
		a Spartanburg Herald-Journal Web site."

	^description! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
title: anObject
	"Set the value of title"

	title _ anObject! !

!SLBlog methodsFor: 'accessing' stamp: 'avi 10/25/2003 22:54'!
username: aString
	username _ aString! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
stories: anObject
	"Set the value of stories"

	stories _ anObject! !

!SLBlog methodsFor: 'initialize-release' stamp: 'avi 2/7/2004 00:22'!
initialize
	name _ ''.
	stories _ Set new.
	title _ ''.
	description _ ''.
	username _ 'blog'.
	passwordHash _ ''.! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/26/2003 15:48'!
passwordHash
	"Answer the value of passwordHash"

	^ passwordHash! !

!SLBlog methodsFor: 'initialize-release' stamp: 'mas 10/24/2003 20:25'!
initializeWithName: aString
	self initialize.
	name _ aString.
	title _ name.! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
name: anObject
	"Set the value of name"

	name _ anObject! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 12:03'!
save
	SLBlogStore current storeBlog: self! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
description: anObject
	"Set the value of description"

	description _ anObject! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 16:50'!
storyWithId: aUUID
	^ stories detect: [:ea | ea id = aUUID] ifNone: [self error: 'No story with id ', aUUID asString]! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 16:55'!
verifyPassword: password forUser: userString 
	^ userString = username and: [passwordHash = (self hash: password)]! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 2/7/2004 00:20'!
hash: aString
	^ aString isEmpty ifTrue: [''] ifFalse: [SecureHashAlgorithm new hashMessage: aString]! !

!SLBlog class methodsFor: 'instance creation' stamp: 'avi 10/23/2003 11:39'!
name: aString
	^ self basicNew initializeWithName: aString! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 11:46'!
addChild: aStory
	^ stories add: aStory! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:35'!
allStories
	^ stories! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:55'!
maxStories
	^ 10! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:57'!
recentStories
	^ self sortedStories first: (self maxStories min: stories size)! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:31'!
storiesOnDate: aDate
	^ stories select: [:ea | ea date = aDate]! !

!SLBlog methodsFor: 'syndication-required elements' stamp: 'mas 10/24/2003 01:01'!
title
	"The name of the channel. It's how people refer to your service."
	"If you have an HTML website that contains the same information
	as your RSS file, the title of your channel should be the same as
	the title of your website."
	"Example:	GoUpstate.com News Headlines"

	^title! !

!SLBlog methodsFor: 'accessing' stamp: 'avi 10/25/2003 23:22'!
username
	^ username! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:32'!
hasStoriesOnDate: aDate
	^ (self storiesOnDate: aDate) isEmpty not! !

!SLBlog methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:21'!
name
	^ name! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 23:12'!
setPassword: passwordString forUser: userString
	self username: userString; password: passwordString! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
stories
	"Answer the value of stories"

	^ stories! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'mas 10/25/2003 23:38'!
deleteChild: anSLStory
	stories remove: anSLStory ifAbsent: [].
	self save.! !

!SLBlog methodsFor: 'private-accessing' stamp: 'mas 10/26/2003 15:48'!
passwordHash: anObject
	"Set the value of passwordHash"

	passwordHash _ anObject! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:35'!
sortedStories
	^ stories asSortedCollection: [:a :b | a timeStamp >= b timeStamp]! !

!SLBlog methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:54'!
password: aString
	passwordHash _ self hash: aString! !

!SLBlog class methodsFor: 'instance creation' stamp: 'mas 10/24/2003 20:22'!
new
	^ self basicNew initialize! !

Object subclass: #SLCss
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLCss class methodsFor: 'as yet unclassified' stamp: 'lr 10/26/2003 10:14'!
standardCss
^'BODY {
	BACKGROUND: #eee; MARGIN: 20px
}
A {
	FONT-WEIGHT: bold; COLOR: #003366; TEXT-DECORATION: none
}
A:link {
	COLOR: #003366; TEXT-DECORATION: none
}
A:visited {
	COLOR: #003366; TEXT-DECORATION: none
}
A:active {
	COLOR: #ffcc66
}
A:hover {
	COLOR: #ffcc66
}

H1 {
	FONT-SIZE: x-large; PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H2 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H3 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
DIV.title {
	BORDER-RIGHT: #fff 1px solid; PADDING-RIGHT: 15px; BORDER-TOP: #fff 1px solid; PADDING-LEFT: 15px; FONT-WEIGHT: bold; FONT-SIZE: x-large; BACKGROUND: #003366; PADDING-BOTTOM: 15px; BORDER-LEFT: #fff 1px solid; COLOR: #fff; PADDING-TOP: 15px; FONT-FAMILY: georgia, verdana, arial, sans-serif
}


.title A {
	FONT-SIZE: x-large; COLOR: #fff; FONT-FAMILY: georgia, verdana, arial, sans-serif; TEXT-DECORATION: none
}
.title A:link {
	FONT-SIZE: x-large; COLOR: #fff; FONT-FAMILY: georgia, verdana, arial, sans-serif; TEXT-DECORATION: none
}
.title A:visited {
	FONT-SIZE: x-large; COLOR: #fff; FONT-FAMILY: georgia, verdana, arial, sans-serif; TEXT-DECORATION: none
}
.title A:active {
	FONT-SIZE: x-large; COLOR: #fff; FONT-FAMILY: georgia, verdana, arial, sans-serif; TEXT-DECORATION: none
}
.title A:hover {
	FONT-SIZE: x-large; COLOR: #fff; FONT-FAMILY: georgia, verdana, arial, sans-serif; TEXT-DECORATION: none
}

DIV.titleDescription {
	FONT-WEIGHT: bold; FONT-SIZE: x-small; BACKGROUND: #003366; TEXT-TRANSFORM: none; COLOR: #fff; FONT-FAMILY: verdana, arial, sans-serif
}

DIV.mainContent {
	PADDING-RIGHT: 15px; PADDING-LEFT: 15px; BACKGROUND: #fff; PADDING-BOTTOM: 15px; PADDING-TOP: 15px; BORDER-RIGHT: #fff 1px solid; BORDER-TOP: #fff 1px solid; BACKGROUND: #fff; FLOAT: left; MARGIN-BOTTOM: 20px; BORDER-LEFT: #fff 1px solid; WIDTH: 60%; MARGIN-RIGHT: 15px; BORDER-BOTTOM: #fff 1px solid; POSITION: relative;
}

DIV.mainBody {
	BACKGROUND: white
}


DIV.sideBar {
	BORDER-RIGHT: #fff 1px solid; PADDING-RIGHT: 15px; BORDER-TOP: #fff 1px solid; PADDING-LEFT: 15px; BACKGROUND: #999; PADDING-BOTTOM: 15px; BORDER-LEFT: #fff 1px solid; PADDING-TOP: 15px; BORDER-BOTTOM: #fff 1px solid
}

P.blogPostTitle {
	FONT-WEIGHT: bold;
}

.blogStamp {
	PADDING-TOP 16px; FONT-SIZE: x-small; MARGIN-BOTTOM: 25px; COLOR: #000000; FONT-FAMILY: verdana, arial, sans-serif
}

.blogPost {
	PADDING-BOTTOM: 15px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #fff; COLOR: #666; LINE-HEIGHT: 150%; FONT-FAMILY: georgia, verdana, arial, sans-serif
}
.blogPost A {
	FONT-WEIGHT: normal; TEXT-DECORATION: underline
}
.blogPost A:link {
	FONT-WEIGHT: normal; TEXT-DECORATION: underline
}
.blogPost A:visited {
	FONT-WEIGHT: normal; TEXT-DECORATION: underline
}
.blogPost A:active {
	FONT-WEIGHT: normal; TEXT-DECORATION: underline
}
.blogPost A:hover {
	FONT-WEIGHT: normal; TEXT-DECORATION: underline
}




.blogDate {
	FONT-WEIGHT: bold; FONT-SIZE: small; MARGIN-BOTTOM: 10px; COLOR: #666; BORDER-BOTTOM: #999 1px solid; FONT-FAMILY: georgia, verdana, arial, sans-serif
}

.blogPostTitle {
	FONT-SIZE: small; TEXT-TRANSFORM: uppercase; COLOR: #000000; FONT-FAMILY: verdana, arial, sans-serif
}

.posted {
	FONT-SIZE: x-small; MARGIN-BOTTOM: 25px; COLOR: #000000; FONT-FAMILY: verdana, arial, sans-serif
}

.recentEntries {
	PADDING-RIGHT: 2px; MARGIN-TOP: 10px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #999; PADDING-BOTTOM: 2px; COLOR: #fff; PADDING-TOP: 2px; BORDER-BOTTOM: #fff 1px dotted; FONT-FAMILY: georgia, verdana, arial, sans-serif; LETTER-SPACING: 0.1em; TEXT-ALIGN: center
}

.archiveEntries {
	PADDING-RIGHT: 2px; MARGIN-TOP: 10px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #999; PADDING-BOTTOM: 2px; COLOR: #fff; PADDING-TOP: 2px; BORDER-BOTTOM: #fff 1px dotted; FONT-FAMILY: georgia, verdana, arial, sans-serif; LETTER-SPACING: 0.1em; TEXT-ALIGN: center
}

.syndicate {
	PADDING-RIGHT: 2px; MARGIN-TOP: 10px; PADDING-LEFT: 2px; FONT-WEIGHT: bold; FONT-SIZE: xx-small; BACKGROUND: #ccc; PADDING-BOTTOM: 2px; LINE-HEIGHT: 140%; PADDING-TOP: 2px; FONT-FAMILY: verdana, arial, sans-serif; TEXT-ALIGN: center
}

DIV.sideEntry {
	MARGIN-LEFT: 10px; PADDING-RIGHT: 2px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #999; PADDING-BOTTOM: 2px; COLOR: #333; LINE-HEIGHT: 140%; PADDING-TOP: 2px; FONT-FAMILY: verdana, arial, sans-serif
}
#sideBar UL {
	PADDING-RIGHT: 0px; PADDING-LEFT: 10px; FONT-SIZE: 85%; PADDING-BOTTOM: 0px; MARGIN: 0px 0px 33px; PADDING-TOP: 0px; LIST-STYLE-TYPE: none
}

.calendar {
	TEXT-ALIGN: center;  MARGIN-LEFT: 10px; PADDING-RIGHT: 2px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; FONT-SIZE: 85%; BACKGROUND: #999; PADDING-BOTTOM: 2px; COLOR: #333; LINE-HEIGHT: 140%; PADDING-TOP: 16px; FONT-FAMILY: verdana, arial, sans-serif
}


.calendarCaption {
	PADDING-RIGHT: 2px; MARGIN-TOP: 10px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; BACKGROUND: #999; PADDING-BOTTOM: 2px; COLOR: #fff; PADDING-TOP: 2px; BORDER-BOTTOM: #fff 1px dotted; FONT-FAMILY: georgia, verdana, arial, sans-serif; LETTER-SPACING: 0.1em; TEXT-ALIGN: center
}

.calendar table { 
margin-left: auto; 
margin-right: auto; 
}

tr.calendarTitle {
	font-size: 90%; COLOR: #003366; TEXT-DECORATION: none ; FONT-WEIGHT: bold
}

.calendar td {
	TEXT-ALIGN: center;  MARGIN-LEFT: 10px; PADDING-RIGHT: 2px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; FONT-SIZE: 80%; BACKGROUND: #999; PADDING-BOTTOM: 2px; COLOR: #333; LINE-HEIGHT: 140%; PADDING-TOP: 2px; FONT-FAMILY: verdana, arial, sans-serif
}

.calendarTitle td {
	font-size: 75%; COLOR: #003366; TEXT-DECORATION: none ; FONT-WEIGHT: bold
}

.calendarArchiveDate {
	TEXT-ALIGN: center;  MARGIN-LEFT: 10px; PADDING-RIGHT: 2px; PADDING-LEFT: 2px; FONT-WEIGHT: normal; FONT-SIZE: 80%; BACKGROUND: lightgrey; PADDING-BOTTOM: 2px; COLOR: #333; LINE-HEIGHT: 140%; PADDING-TOP: 2px; FONT-FAMILY: verdana, arial, sans-serif
}

.commentBody {
	PADDING-BOTTOM: 15px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #fff; COLOR: #666; LINE-HEIGHT: 150%; FONT-FAMILY: georgia, verdana, arial, sans-serif
}

.commentBody td {
	PADDING-BOTTOM: 15px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #fff; COLOR: #666; LINE-HEIGHT: 150%; FONT-FAMILY: georgia, verdana, arial, sans-serif
}


.commentTitle {
	FONT-WEIGHT: bold; FONT-SIZE: small; MARGIN-BOTTOM: 10px; COLOR: #666; BORDER-BOTTOM: #999 1px solid; FONT-FAMILY: georgia, verdana, arial, sans-serif
}

.commentStamp {
	PADDING-TOP 16px; FONT-SIZE: x-small; MARGIN-BOTTOM: 8px; FONT-FAMILY: verdana, arial, sans-serif
}

textArea.commentTextArea {
	width : 100%;
	height: 200px;;
}

.newStory {
 TEXT-ALIGN: left ; PADDING-RIGHT: 15px; 
}

.newStory A {
	COLOR: darkgreen ; TEXT-DECORATION: underline
}

.configure {
 TEXT-ALIGN: left;
}

.configure A {
	COLOR: darkgreen  ; TEXT-DECORATION: underline
}

.login A {
COLOR: #003366;  ; TEXT-DECORATION: underline
}

.editStory {
	PADDING-BOTTOM: 15px; FONT-WEIGHT: normal; FONT-SIZE: small; BACKGROUND: #fff; COLOR: #666; LINE-HEIGHT: 150%; FONT-FAMILY: georgia, verdana, arial, sans-serif
}

'! !

!SLCss class methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 17:15'!
blaineCss
^'BODY {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; BACKGROUND: #f6f6f6; PADDING-BOTTOM: 0px; MARGIN: 0px; COLOR: #000000; PADDING-TOP: 0px; FONT-FAMILY: "Trebuchet MS",Trebuchet,Verdana,Sans-Serif
}
A {
	COLOR: #800080
}
A:hover {
	COLOR: #e0ad12
}
DIV.title {
	PADDING-RIGHT: 0px; BORDER-TOP: #800000 1px solid; PADDING-LEFT: 0px; BACKGROUND: #800080; PADDING-BOTTOM: 0px; MARGIN: 0px; COLOR: white; PADDING-TOP: 0px; BORDER-BOTTOM: #800000 1px dotted
}
DIV.titleDescription {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; BACKGROUND: none transparent scroll repeat 0% 0%; PADDING-BOTTOM: 0px; MARGIN: 7px 12% 7px 5%; FONT: bold 85% Verdana,Sans-Serif; COLOR: #ffde80; PADDING-TOP: 0px
}
DIV.mainContent {
	float: right ; width: 60%; PADDING-RIGHT: 7%; PADDING-LEFT: 3%; PADDING-BOTTOM: 10px; BORDER-LEFT: #800000 1px dotted; PADDING-TOP: 30px
}

.title A {
	COLOR: #f5deb3; TEXT-DECORATION: none ;
}

DIV.sideBar {
	float: left ; PADDING-RIGHT: 4px; PADDING-LEFT: 10px; PADDING-BOTTOM: 0px; MARGIN: 20px 0px 0px 0px; PADDING-TOP: 0px; TEXT-ALIGN: left
}


P.blogPostTitle {
	FONT-WEIGHT: bold;
}

.blogStamp {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; FONT-SIZE: 90%; PADDING-BOTTOM: 0px; MARGIN: 0px; COLOR: #444444; PADDING-TOP: 0px
}

.blogStamp A {
	COLOR: #800000; BORDER-TOP-STYLE: none; BORDER-RIGHT-STYLE: none; BORDER-LEFT-STYLE: none; TEXT-DECORATION: none; BORDER-BOTTOM-STYLE: none
}

.blogStamp A:hover {
	TEXT-DECORATION: underline
}

H1 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H2 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H3 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H4 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H5 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H6 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px
}
H1 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 5%; BACKGROUND: #800080; PADDING-BOTTOM: 10px; FONT: bold 175% Verdana,Sans-Serif; COLOR: #f5deb3; PADDING-TOP: 25px; BORDER-BOTTOM: #ffde80 1px solid; LETTER-SPACING: -2px
}
H2 {
	FONT-WEIGHT: bold; COLOR: #9e5205; FONT-FAMILY: Verdana,Sans-Serif; LETTER-SPACING: -1px
}
H3 {
	FONT-SIZE: 100%; MARGIN: 10px 0px 0px; COLOR: #700070
}
H4 {
	COLOR: #aa0033
}
H6 {
	FONT-SIZE: 100%; COLOR: #800080
}
.blogPost {
	FONT-SIZE: 80%; MARGIN: 0px 0px 30px
}
.blogPost STRONG {
	FONT-WEIGHT: bold; COLOR: #000000
}
#sideBar UL {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; FONT-SIZE: 85%; PADDING-BOTTOM: 0px; MARGIN: 0px 0px 33px; PADDING-TOP: 0px; LIST-STYLE-TYPE: none
}
#sideBar LI {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; FONT-SIZE: 85%; PADDING-BOTTOM: 0px; MARGIN: 0px; PADDING-TOP: 0px; LIST-STYLE-TYPE: none
}
#sideBar UL A {
	PADDING-RIGHT: 2px; PADDING-LEFT: 2px; PADDING-BOTTOM: 2px; MARGIN: 1px; COLOR: #999999; BORDER-TOP-STYLE: none; PADDING-TOP: 2px; BORDER-RIGHT-STYLE: none; BORDER-LEFT-STYLE: none; TEXT-DECORATION: none; BORDER-BOTTOM-STYLE: none
}
#sideBar UL A:link {
	COLOR: #800000
}
#sideBar UL A:visited {
	COLOR: #800000
}
#sideBar UL A:active {
	COLOR: #ff0000
}
#sideBar UL A:hover {
	COLOR: #de7008; TEXT-DECORATION: none
}
PRE {
	COLOR: #999999
}
CODE {
	COLOR: #999999
}
STRIKE {
	COLOR: #999999
}
.syndicate {
	FONT-SIZE: 90%; COLOR: #800080 ; PADDING-LEFT: 8px;
}

.recentEntries {
	FONT-SIZE: 100%; COLOR: #800080
}

.archiveEntries {
	FONT-SIZE: 100%; COLOR: #800080
}

Div.calendar {
	PADDING-BOTTOM: 20px ; PADDING-TOP: 15px; COLOR: #800000; 
}

.calendar {
	font-size: 80%
}

.calendarCaption {
	FONT-SIZE: 100%; FONT-WEIGHT: bold; COLOR: #800080
}


tr.calendarTitle {
	FONT-SIZE: 90%; COLOR: #800080
	
}

.calendar td {
	font-size: 80% ; TEXT-ALIGN: center ;
	
}

.calendarTitle td {
	
}

td.calendarArchiveDate {
	BACKGROUND: lightGrey ; font-size: 80% ; TEXT-ALIGN: center ;
}

.commentTitle {
	PADDING-TOP: 10px; COLOR: #800000;
}

.commentStamp {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; FONT-SIZE: 90%; PADDING-BOTTOM: 0px; MARGIN: 0px; COLOR: #444444; PADDING-TOP: 0px
}

textArea.commentTextArea {
	width : 100%;
	height: 200px;;
}

'! !

!SLCss class methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:54'!
defaultCss
	^ self standardCss! !

Object subclass: #SLRssWriter
	instanceVariableNames: 'blog stream shouldInline stories baseUrl'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-RSS'!

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 22:30'!
addItemLink: aStory to: anXMLElement
		self addElementNamed: 'link' withString: baseUrl, '/', aStory id asString to: anXMLElement.
! !

!SLRssWriter class methodsFor: 'writing' stamp: 'mas 10/24/2003 00:05'!
writeBlog: anSLBlog on: aStream
	self new writeBlog: anSLBlog on: aStream
! !

!SLRssWriter methodsFor: 'writing' stamp: 'avi 2/6/2004 22:29'!
writeBlog: anSLBlog on: aStream
	blog _ anSLBlog.
	stream _ aStream.
	shouldInline _ true.
	stories _ blog sortedStories.
	baseUrl _ ''.
	self write.! !

!SLRssWriter methodsFor: 'writing' stamp: 'mas 10/24/2003 00:32'!
write
	self rssDocument printOn: stream! !

!SLRssWriter methodsFor: 'writing' stamp: 'mas 10/26/2003 01:56'!
writeBlog: anSLBlog stories: aCollection on: aStream withBaseUrl: aString
	blog _ anSLBlog.
	stream _ aStream.
	shouldInline _ false.
	stories _ aCollection.
	baseUrl _ aString.
	self write.! !

!SLRssWriter methodsFor: 'document building' stamp: 'mas 10/24/2003 00:17'!
channelElement
	| node |
	node _ XMLElement named: 'channel'.
	self addChannelElementsTo: node.
	^node
! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 15:39'!
addItemComments: aStory to: anXMLElement
	| node |
	aStory comments notEmpty ifTrue: [
		node _ XMLElement named: 'includedComments:comment-collection'.
		anXMLElement addElement: node.
		aStory comments do: [:each |
			self addCommentElement: each to: node]]
! !

!SLRssWriter methodsFor: 'document building' stamp: 'mas 10/26/2003 15:58'!
addNonstandardChannelElementsTo: anXMLElement
	shouldInline ifTrue: [
		self addElementNamed: 'sblog:username' withString: blog username to: anXMLElement.
		self addElementNamed: 'sblog:passwordHash' withString: blog passwordHash asString to: anXMLElement].! !

!SLRssWriter methodsFor: 'document building' stamp: 'mas 10/26/2003 15:52'!
addChannelElementsTo: anXMLNodeWithElements
	self addRequiredChannelElementsTo: anXMLNodeWithElements.
	self addOptionalChannelElementsTo: anXMLNodeWithElements.
	self addNonstandardChannelElementsTo: anXMLNodeWithElements.
	self addChannelItemsElementsTo: anXMLNodeWithElements.! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 22:30'!
addItemElement: aStory to: anXMLElement
	| node |
	node _ XMLElement named: 'item'.
	self addItemElements: aStory to: node.
	anXMLElement addElement: node.! !

!SLRssWriter class methodsFor: 'writing' stamp: 'mas 10/26/2003 01:54'!
writeBlog: anSLBlog stories: aCollection on: aStream withBaseUrl: aString
	self new writeBlog: anSLBlog stories: aCollection on: aStream withBaseUrl: aString
! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 15:40'!
addCommentElements: aComment to: anXMLElement
	"Our model doesn't implement some of these yet, so they are set to nil."
	self addElementNamed: 'includedComments:guid' withString: nil to: anXMLElement.
	self addElementNamed: 'includedComments:puid' withString: aComment parent id asString to: anXMLElement.
	self addElementNamed: 'includedComments:author' withString: aComment author to: anXMLElement.
	self addElementNamed: 'includedComments:content' withString: aComment text to: anXMLElement.
	self addElementNamed: 'includedComments:pubDate' withString: aComment timeStamp printHttpFormat to: anXMLElement.
! !

!SLRssWriter methodsFor: 'writing' stamp: 'avi 2/6/2004 22:29'!
writeBlog: anSLBlog stories: aCollection on: aStream
	blog _ anSLBlog.
	stream _ aStream.
	shouldInline _ false.
	stories _ aCollection.
	baseUrl _ ''.
	self write.! !

!SLRssWriter methodsFor: 'document building' stamp: 'mas 10/24/2003 00:17'!
rssDocument
	^(XMLDocument new)
		version: '1.0';
		encoding: 'UTF-8';
		addElement: self rssElement;
		yourself! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 22:30'!
addChannelItemsElementsTo: anXMLNodeWithElements
	stories do: [:each |
		self addItemElement: each to: anXMLNodeWithElements]! !

!SLRssWriter methodsFor: 'document building' stamp: 'mas 10/25/2003 13:35'!
rssElement
	^(XMLElement named: 'rss')
		setAttributes: 
			((Dictionary new)
				at: 'version' put: '2.0';
				at: 'xmlns:includedComments' put: 'http://www.laudably.com/rss2-comments';
				yourself);
		addElement: self channelElement;
		yourself
! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 15:39'!
addCommentElement: aComment to: anXMLElement
	| node |
	node _ XMLElement named: 'includedComments:comment'.
	self addCommentElements: aComment to: node.
	anXMLElement addElement: node.! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 22:30'!
addItemElements: aStory to: anXMLElement
	"Our model doesn't implement some of these yet, so they are set to nil."
	self addElementNamed: 'title' withString: aStory title to: anXMLElement.
	self addItemLink: aStory to: anXMLElement.
	self addElementNamed: 'description' withString: aStory text to: anXMLElement.
	self addElementNamed: 'author' withString: nil to: anXMLElement.
	self addElementNamed: 'category' withString: nil to: anXMLElement.
	"self addElementNamed: 'comments' withString: nil to: anXMLElement."
	self addElementNamed: 'enclosure' withString: nil to: anXMLElement.
	self addElementNamed: 'guid' withString: aStory id asString to: anXMLElement.
	self addElementNamed: 'pubDate' withString: aStory timeStamp printHttpFormat to: anXMLElement.
	self addElementNamed: 'source' withString: nil to: anXMLElement.
	self addItemComments: aStory to: anXMLElement.
! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/29/2004 12:07'!
addElementNamed: nameString withString: contentString to:  anXMLElement 
	contentString isEmptyOrNil ifFalse: [
		| node |
		node _ XMLElement named: nameString.
		node addContent: (XMLStringNode string: contentString).
		anXMLElement addElement: node].! !

!SLRssWriter methodsFor: 'document building' stamp: 'avi 2/6/2004 15:33'!
addRequiredChannelElementsTo: anXMLElement
	self addElementNamed: 'title' withString: blog title to: anXMLElement.
	self addElementNamed: 'link' withString: baseUrl to: anXMLElement.
	self addElementNamed: 'description' withString: blog description to: anXMLElement.! !

!SLRssWriter methodsFor: 'document building' stamp: 'mas 10/25/2003 14:25'!
addOptionalChannelElementsTo: anXMLElement
	self addElementNamed: 'language' withString: nil to: anXMLElement.
	self addElementNamed: 'copyright' withString: nil to: anXMLElement.
	self addElementNamed: 'managingEditor' withString: nil to: anXMLElement.
	self addElementNamed: 'webMaster' withString: nil to: anXMLElement.
	self addElementNamed: 'pubDate' withString: nil to: anXMLElement.
	self addElementNamed: 'lastBuildDate' withString: nil to: anXMLElement.
	self addElementNamed: 'category' withString: nil to: anXMLElement.
	self addElementNamed: 'generator' withString: nil to: anXMLElement.
	self addElementNamed: 'docs' withString: nil to: anXMLElement.
	self addElementNamed: 'cloud' withString: nil to: anXMLElement.
	self addElementNamed: 'ttl' withString: nil to: anXMLElement.
	self addElementNamed: 'image' withString: nil to: anXMLElement.
	self addElementNamed: 'rating' withString: nil to: anXMLElement.
	self addElementNamed: 'textInput' withString: nil to: anXMLElement.
	self addElementNamed: 'skipHours' withString: nil to: anXMLElement.
	self addElementNamed: 'skipDays' withString: nil to: anXMLElement.
	! !

Object subclass: #SLPost
	instanceVariableNames: 'text timeStamp parent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-Model'!

!SLPost methodsFor: 'initialize-release' stamp: 'mas 10/25/2003 16:16'!
initializeWithParent: aParent
	self initialize.
	parent _ aParent.! !

!SLPost methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 12:03'!
save
	parent save! !

!SLPost methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:48'!
text
	^ text! !

SLPost subclass: #SLStory
	instanceVariableNames: 'title id comments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-Model'!

!SLStory methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 11:50'!
blog
	^ self parent! !

!SLStory methodsFor: 'accessing' stamp: 'avi 10/23/2003 12:33'!
date
	^ self timeStamp date! !

!SLStory methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:54'!
comments: anObject
	"Set the value of comments"

	comments _ anObject! !

!SLStory methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:48'!
time
	^ self timeStamp time! !

!SLStory methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 11:52'!
defaultTitle
	^ 'Untitled'! !

!SLStory methodsFor: 'initialize-release' stamp: 'mas 10/25/2003 16:18'!
initialize
	super initialize.
	id _ UUID new.
	comments _ OrderedCollection new.
	title _ self defaultTitle.
! !

!SLStory methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:54'!
id: anObject
	"Set the value of id"

	id _ anObject! !

!SLStory methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 11:47'!
addChild: aComment
	^ comments add: aComment! !

!SLStory methodsFor: 'as yet unclassified' stamp: 'mas 10/25/2003 23:39'!
deleteChild: aComment
	comments remove: aComment ifAbsent: [].
	self save.! !

!SLStory methodsFor: 'accessing' stamp: 'avi 10/24/2003 17:25'!
title
	^ title! !

!SLStory methodsFor: 'accessing' stamp: 'avi 10/24/2003 17:25'!
title: aString
	title _ aString! !

!SLStory methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:50'!
id
	^ id! !

!SLStory methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 16:52'!
hasComments
	^ self comments isEmpty not! !

!SLStory methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:50'!
comments
	^ comments! !

!SLPost methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
parent: anObject
	"Set the value of parent"

	parent _ anObject! !

SLPost subclass: #SLComment
	instanceVariableNames: 'author email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-Model'!

!SLComment methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:52'!
story
	^ self parent! !

!SLComment methodsFor: 'accessing' stamp: 'avi 10/24/2003 17:26'!
email: aString
	email _ aString! !

!SLComment methodsFor: 'initialize-release' stamp: 'mas 10/25/2003 16:17'!
initialize
	super initialize.
	author _ 'anonymous'.! !

!SLComment methodsFor: 'accessing' stamp: 'avi 10/24/2003 17:26'!
email
	^ email! !

!SLComment methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:38'!
author: aString
	author _ aString! !

!SLComment methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:38'!
author
	^ author! !

!SLPost methodsFor: 'instance creation' stamp: 'avi 10/23/2003 11:48'!
text: aString
	text _ aString! !

!SLPost methodsFor: 'as yet unclassified' stamp: 'mas 10/25/2003 23:37'!
delete
	parent deleteChild: self.! !

!SLPost class methodsFor: 'instance creation' stamp: 'avi 10/23/2003 11:49'!
parent: aParent
	^ self basicNew initializeWithParent: aParent! !

!SLPost methodsFor: 'initialize-release' stamp: 'mas 10/25/2003 16:17'!
initialize
	text _ ''.
	timeStamp _ TimeStamp current.! !

!SLPost methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:49'!
timeStamp
	^ timeStamp! !

!SLPost methodsFor: 'private-accessing' stamp: 'mas 10/24/2003 15:55'!
timeStamp: anObject
	"Set the value of timeStamp"

	timeStamp _ anObject! !

!SLPost class methodsFor: 'instance creation' stamp: 'mas 10/25/2003 16:14'!
new
	^ self basicNew initialize! !

!SLPost methodsFor: 'accessing' stamp: 'avi 10/23/2003 11:49'!
parent
	^ parent! !

!SLPost methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 12:03'!
post
	parent addChild: self; save! !

Object subclass: #SLRssReader
	instanceVariableNames: 'blog'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-RSS'!

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/25/2003 16:51'!
readCommentElementsWithParent: aStory from: anXMLElement
	| comment |
	comment _ SLComment parent: aStory.
	aStory addChild: comment.
	anXMLElement elementsDo: [:eachElement |
		eachElement name caseOf: {
			['includedComments:guid'] -> [].
			['includedComments:puid'] -> ["(UUID fromString: eachElement contentString)"].
			['includedComments:author'] -> [comment author: eachElement contentString].
			['includedComments:content'] -> [comment text: eachElement contentString].
			['includedComments:pubDate'] -> [comment timeStamp:
				(TimeStamp fromRfc822String: eachElement contentString)]}].! !

!SLRssReader class methodsFor: 'reading' stamp: 'mas 10/25/2003 08:31'!
readBlogNamed: aString from: aStream
	^self new readBlogNamed: aString from: aStream ! !

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/24/2003 13:46'!
readRssDocumentFrom: aStream
	self readChannelFrom: (XMLDOMParser parseDocumentFrom: aStream).! !

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/24/2003 13:38'!
readChannelFrom: anXMLDocument
	self readChannelElementsFrom: (anXMLDocument firstTagNamed: #channel)
! !

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/25/2003 16:49'!
readCommentsWithParent: aStory from: anXMLElement
	anXMLElement elementsDo: [:eachElement |
		self readCommentElementsWithParent: aStory from: eachElement].! !

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/26/2003 15:56'!
readChannelElementsFrom: anXMLElement
	anXMLElement elementsDo: [:eachElement |
		eachElement name caseOf: {
			['sblog:username'] -> [blog username: eachElement contentString].
			['sblog:passwordHash'] -> [blog passwordHash: eachElement contentString asNumber].
			['title'] -> [blog title: eachElement contentString].
			['description'] -> [blog description: eachElement contentString].
			['item'] -> [self readItemElementsFrom: eachElement]}].! !

!SLRssReader methodsFor: 'reading' stamp: 'mas 10/25/2003 08:21'!
readBlogNamed: aString from: aStream 
	blog _ SLBlog name: aString.
	self readRssDocumentFrom: aStream.
	^ blog! !

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/25/2003 15:24'!
readCommentElementsFrom: anXMLElement
	| story |
	story _ SLStory new.
	blog addChild: story.
	story parent: blog.
	anXMLElement elementsDo: [:eachElement |
		eachElement name caseOf: {
			['title'] -> [story title: eachElement contentString].
			['description'] -> [story text: eachElement contentString].
			['guid'] -> [story id: 
				(UUID fromString: eachElement contentString)].
			['pubDate'] -> [story timeStamp:
				(TimeStamp fromRfc822String: eachElement contentString)].
			['includedComments:comment-collection'] -> [self readCommentElementsFrom: eachElement]}].! !

!SLRssReader methodsFor: 'private-reading' stamp: 'avi 2/29/2004 12:00'!
readItemElementsFrom: anXMLElement
	| story |
	story _ SLStory new.
	blog addChild: story.
	story parent: blog.
	anXMLElement elementsDo: [:eachElement |
		eachElement name caseOf: {
			['title'] -> [story title: eachElement contentString].
			['description'] -> [story text: eachElement contentString].
			['guid'] -> [story id: 
				(UUID fromString: eachElement contentString)].
			['pubDate'] -> [story timeStamp:
				(TimeStamp fromRfc822String: eachElement contentString)].
			['includedComments:comment-collection'] -> [self readCommentsWithParent: story from: eachElement]}
		otherwise: []]! !

!SLRssReader methodsFor: 'private-reading' stamp: 'mas 10/25/2003 15:26'!
readCommentsFrom: anXMLElement
	anXMLElement elementsDo: [:eachElement |
		self readCommentElementsFrom: eachElement].! !

WAComponent subclass: #SLFrontPage
	instanceVariableNames: 'blog calendar storyList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:31'!
blog: aBlog
	blog _ aBlog! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:09'!
initialize
	storyList _ SLStoryList new
				storyBlock: [blog recentStories];
				selectBlock: [:story | self chooseStory: story].
	calendar _ WAMiniCalendar new
				canSelectBlock: [:date | blog hasStoriesOnDate: date];
				selectBlock: [:date | self chooseDate: date]! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:07'!
login
	(self call: (WALoginDialog new authenticator: blog))
		ifNotNil: [self isolate:
					[self call: (SLAdminPage new blog: blog)]]! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:38'!
renderSideBarOn: html
	html render: calendar.
	html cssClass: 'syndicate'; paragraph: [
		html anchorWithUrl: (self session application basePath, '/', blog name, '/rss/recent.xml') do:
			[html attributes border: 0.
			html image: 'http://www.scripting.com/images/xml.gif' altText: 'xml'].  
	].
	self renderLoginOn: html.! !

SLFrontPage subclass: #SLAdminPage
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI-Admin'!

!SLAdminPage methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:00'!
renderLoginOn: html
	html divClass: 'login' with: [html anchorWithAction: [self answer] text: 'logout']! !

!SLAdminPage methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:37'!
chooseStory: aStory
	(self editStory: aStory) ifTrue: [aStory save]! !

!SLAdminPage methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:25'!
configure
	self call: (SLBlogSetup new blog: blog)! !

!SLAdminPage methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:46'!
renderSideBarOn: html
	html spanClass: 'newStory' with: [html anchorWithAction: [self newStory] text: 'New Story'].
	html break.
	html spanClass: 'configure' with: [html anchorWithAction: [self configure] text: 'Configure'].
	
	super renderSideBarOn: html.! !

!SLAdminPage methodsFor: 'as yet unclassified' stamp: 'mas 10/25/2003 23:14'!
editStory: aStory
	^ storyList call: (SLStoryEditor story: aStory) ! !

!SLAdminPage methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:35'!
newStory
	| story shouldCommit |
	story _ SLStory parent: blog.
	shouldCommit _ self editStory: story.
	shouldCommit ifTrue: [story post].! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:27'!
chooseDate: aDate
	storyList storyBlock: [blog storiesOnDate: aDate]! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:27'!
chooseStory: aStory
	calendar date: nil.
	storyList storyBlock: [Array with: aStory]! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 14:35'!
renderContentOn: html
	html divClass: 'mainContent' with: storyList.
	html divClass: 'sideBar' with: [self renderSideBarOn: html].! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:57'!
renderLoginOn: html
	html divClass: 'login' with: [html anchorWithAction: [self login] text: 'login']! !

!SLFrontPage methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:33'!
children
	^ Array with: calendar with: storyList! !

WAComponent subclass: #SLCommentViewer
	instanceVariableNames: 'story'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLCommentViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:28'!
story: aStory
	story _ aStory! !

!SLCommentViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:19'!
renderContentOn: html
	story hasComments ifFalse: [^ self].
	html divClass: 'commentTitle' with: [
		html text: 'Comments '.
		self renderAddCommentLinkOn: html
	].
	story comments do: [:ea | self renderComment: ea on: html].! !

!SLCommentViewer methodsFor: 'as yet unclassified' stamp: 'lr 10/26/2003 10:40'!
renderComment: aComment on: html
	html divClass: 'commentStamp' with: [
		html text: aComment author.
		aComment email isEmptyOrNil ifFalse: [
			self renderEmail: aComment email on: html ].
		html text: ', '.
		html text: aComment timeStamp.
	].
	html divClass: 'commentBody' with: [ html blogText: aComment text ].! !

!SLCommentViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:18'!
addComment
	| comment |
	comment _ SLComment parent: story.
	(self call: (SLCommentEditor new story: story; comment: comment))
		ifTrue: [comment post]! !

SLCommentViewer subclass: #SLCommentEditor
	instanceVariableNames: 'comment'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLCommentEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 12:44'!
comment: aComment
	comment _ aComment! !

!SLCommentEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:19'!
renderAddCommentLinkOn: html
	! !

!SLCommentEditor methodsFor: 'as yet unclassified' stamp: 'lr 10/26/2003 10:36'!
renderContentOn: html
	super renderContentOn: html.
	html divClass: 'commentBody' with: [
		html divClass: 'commentTitle' with: 'Add Comment'.
		html cssClass: 'addComment'; form: [
			html layoutTableOfWidth: '100%' do: [
				html tableRowWith: 'Author:' with: [html textInputOn: #author of: comment].
				html tableRowWith: 'Email: ' with: [html textInputOn: #email of: comment].
				html tableRowWith: [
					html cssClass: 'commentTextArea'; textAreaOn: #text of: comment.
				] span: 2.
				html attributes alignCenter.
				html tableRowWith: [
					html submitButtonWithAction: [self answer: true] text: 'Save'.
					html space.
					html submitButtonWithAction: [self answer: false] text: 'Cancel'. 
				] span: 2.
			]
		]
	]! !

!SLCommentViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:19'!
renderAddCommentLinkOn: html
	html spanClass: 'blogStamp' with: [html anchorWithAction: [self addComment] text: 'add']! !

!SLCommentViewer methodsFor: 'as yet unclassified' stamp: 'lr 10/26/2003 10:31'!
renderEmail: aString on: html
	| stream |
	stream _ aString withBlanksTrimmed readStream.
	html text: ' ('; text: (stream upTo: $@).
	stream atEnd ifFalse: [
		html text: ' AT '; text: stream upToEnd ].
	html text: ')'	! !

WAComponent subclass: #SLBlogCreation
	instanceVariableNames: 'configList viewList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI-Admin'!

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:48'!
renderContentOn: html
	html heading: 'SmallBlog Setup'.
	html form: [
		html submitButtonWithAction: [self createBlog] text: 'Create a new blog'.
	].
	html heading: 'Configure an existing blog:' level: 2.
	html render: configList.

	html heading: 'Test a blog:' level: 2.
	html render: viewList.
! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 22:22'!
createBlog
	| blogName |
	blogName _ self request: 'Please choose a short (no spaces) name for your blog:'.
	self configureBlog: (SLBlogStore current blogNamed: blogName)! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:28'!
configureBlog: aBlog
	self call: ((SLBlogSetup new blog: aBlog) addMessage: 'Configuring ', aBlog name printString).
	self answer: aBlog! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 12:39'!
viewBlog: aBlog
	self call: (SLFrame new blog: aBlog)! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 13:01'!
verifyPassword: passString forUser: userString
	^ ((self session application preferenceAt: #adminUser) = userString)
		and: [(self session application preferenceAt: #adminPassword) = passString]! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 23:23'!
children
	^ Array with: configList with: viewList! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 12:45'!
defaultFilters
	^ Array with:
		(WABasicAuthentication new
			realm: 'smallblog';
			authenticator: self)! !

!SLBlogCreation methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:53'!
initialize
	configList _ SLBlogList new onAnswer: [:b | self configureBlog: b].
	viewList _ SLBlogList new onAnswer: [:b | self viewBlog: b].! !

WAComponent subclass: #SLFrame
	instanceVariableNames: 'main blog'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLFrame methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:32'!
children
	^ Array with: main! !

!SLFrame methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:49'!
path
	^ blog name! !

!SLFrame methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:22'!
date: aDate
	main chooseDate: aDate! !

!SLFrame methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 14:33'!
style
	^ SLCss defaultCss! !

!SLFrame methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:22'!
story: aStory
	main chooseStory: aStory! !

!SLFrame methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:34'!
renderContentOn: html
	html title: blog title.
	html divClass: 'title' with: [
		html anchorWithUrl: self session application basePath, '/', blog name do: blog title.
		html divClass: 'titleDescription' with: blog description.
	].
	
	html divClass: 'mainBody' with: main! !

!SLFrame methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:32'!
blog: aBlog
	blog _ aBlog.
	main _ SLFrontPage new blog: aBlog! !

WAComponent subclass: #SLStoryList
	instanceVariableNames: 'storyBlock selectBlock storyViewers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:21'!
storyBlock: aBlock
	storyBlock contents: aBlock! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:14'!
renderStoryGroup: aCollection on: html
	self renderDateHeader: aCollection anyOne date on: html.
	aCollection do:
		[:ea |
		html render: (self storyViewerFor: ea)].! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:25'!
select: aStory
	selectBlock ifNotNil: [selectBlock value: aStory]! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 13:25'!
selectBlock: aBlock
	selectBlock _ aBlock! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 14:18'!
stories
	^ storyBlock contents value! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 03:33'!
children
	^ self stories collect: [:ea | self storyViewerFor: ea]! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:26'!
storyViewerFor: aStory
	^ storyViewers at: aStory ifAbsentPut: [SLStoryViewer new list: self; story: aStory]! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:14'!
initialize
	storyBlock _ WAStateHolder new.
	storyViewers _ Dictionary new.! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 15:46'!
renderDateHeader: aDate on: html
	html divClass: 'blogDate' with: aDate! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 13:52'!
storiesByDate
	| dictionary |
	dictionary _ self stories groupBy: [:ea | ea date] having: [:ea | true].
	^ dictionary keys asSortedCollection reversed collect: [:ea | dictionary at: ea]! !

!SLStoryList methodsFor: 'as yet unclassified' stamp: 'avi 10/23/2003 12:31'!
renderContentOn: html
	self storiesByDate do:
		[:group |
		self renderStoryGroup: group on: html]! !

WAComponent subclass: #SLBlogSetup
	instanceVariableNames: 'blog username password confirmPassword'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI-Admin'!

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 23:14'!
username: aString
	username _ aString! !

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 23:16'!
username
	^ username! !

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 23:21'!
blog: aBlog
	blog _ aBlog.
	username _ blog username.! !

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 23:20'!
renderContentOn: html
	html divClass: 'mainContent' with: [self renderConfigurationOn: html].! !

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 2/7/2004 02:19'!
renderConfigurationOn: html
	html form: [
		html defaultAction: [self save].
		html table: [
			html labelledRowForTextInputOn: #title of: blog size: 30.
			html labelledRowForTextInputOn: #description of: blog size: 30.
			html tableRowWithLabel: 'Owner' column: [
				html textInputOn: #username of: blog.
				html space.
				html attributes submitOnClick.
				html anchorWithAction: [self changePassword] text: 'Change Password'.
			].
			html spacerRow.
			html attributes alignCenter.
			html tableRowWith: [html submitButtonOn: #save of: self] span: 2.
		]
	].
! !

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 2/7/2004 02:20'!
changePassword
	(self call: (WAChangePassword new username: blog username; authenticator: blog))
		ifTrue: [blog save].! !

!SLBlogSetup methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 14:01'!
save
	blog save.
	self answer.! !

WAComponent subclass: #SLStoryViewer
	instanceVariableNames: 'story list commentViewer showComments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 16:54'!
toggleComments
	self showComments: self showComments not! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 16:43'!
commentInfo
	^ self showComments
		ifFalse: [story comments size asString, ' comments, last by ', story comments last author]
		ifTrue: ['hide comments']! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'lr 10/26/2003 10:41'!
renderContentOn: html
	html divClass: 'blogPost' with: [
		self renderTitleOn: html.
		html blogText: story text.
		self renderStampOn: html.
		self showComments ifTrue: [html render: self commentViewer].
	]! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 16:51'!
renderCommentInfoOn: html
	story hasComments
		ifTrue: [html anchorWithAction: [self toggleComments] text: self commentInfo]
		ifFalse: [html anchorWithAction: [self addComment] text: 'add comment'].! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 15:20'!
children
	^ self showComments ifTrue: [Array with: commentViewer] ifFalse: [#()]! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:12'!
list: aStoryList
	list _ aStoryList! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 16:54'!
addComment
	self showComments: true.
	self commentViewer addComment.! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:06'!
story: aStory
	story _ aStory! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:12'!
select
	list select: story! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:22'!
renderTitleOn: html		
	html cssClass: 'blogPostTitle'; paragraph: [
		html anchorWithAction: [self select] text: story title.
	].
! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 16:54'!
showComments: aBoolean
	showComments contents: aBoolean! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:20'!
initialize
	showComments _ WAStateHolder new contents: false! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 16:50'!
renderStampOn: html
	html divClass: 'blogStamp' with: [
		self renderPermalinkOn: html.
		html space.
		html text: story time.
		html space.
		self renderCommentInfoOn: html.
	].
! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:06'!
selectBlock: aBlock
	selectBlock _ aBlock! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 23:26'!
renderPermalinkOn: html
	html anchorWithUrl: self session application basePath, '/', story blog name, '/', story id asString title: story title do: 'link'. 
! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:27'!
commentViewer
	^ commentViewer ifNil: [commentViewer _ SLCommentViewer new story: story]! !

!SLStoryViewer methodsFor: 'as yet unclassified' stamp: 'avi 10/24/2003 15:20'!
showComments
	^ showComments contents! !

WAComponent subclass: #SLStoryEditor
	instanceVariableNames: 'story'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI-Admin'!

!SLStoryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:39'!
save
	story commit.
	self answer: true! !

!SLStoryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:40'!
delete
	(self confirm: 'Are you sure you want to delete "', story title, '"?')
		ifTrue: [ story delete. self cancel ]! !

!SLStoryEditor class methodsFor: 'as yet unclassified' stamp: 'lr 10/23/2003 21:22'!
story: aStory
	^self new
		initializeWithStory: aStory;
		yourself! !

!SLStoryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:39'!
cancel
	self answer: false! !

!SLStoryEditor methodsFor: 'as yet unclassified' stamp: 'avi 10/25/2003 22:39'!
initializeWithStory: aStory
	story _ WAModelProxy on: aStory! !

!SLStoryEditor methodsFor: 'as yet unclassified' stamp: 'lr 10/26/2003 10:10'!
renderContentOn: html
	html form: [
		html text: 'Title:'.
		html attributes style: 'width: 100%'.
		html textInputOn: #title of: story; break.
		html break.
		html text: 'Body:'.
		html attributes style: 'width: 100%'; rows: 20.
		html textAreaOn: #text of: story; break.
		html attributes width: '100%'.
		html table: [
			html tableRow: [
				html attributes align: 'left'.
				html tableData: [
					html submitButtonWithAction: [ self save] text: 'save'.
					html space.
					html submitButtonWithAction: [ self cancel ] text: 'cancel' ].
				html attributes align: 'right'.
				html tableData: [
					html
						submitButtonWithAction: [self delete]
						 text: 'delete this post' ]]]].! !

WAComponent subclass: #SLBlogList
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLBlogList methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 22:36'!
renderContentOn: html
	html list: SLBlogStore current blogs do:
		[:ea |
		html anchorWithAction: [self answer: ea] text: ea title].
		! !

WASystemConfiguration subclass: #SLConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SmallBlog-UI'!

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 13:13'!
deploymentMode
	^ true! !

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 21:52'!
ancestors
	^ Array with: (WASessionConfiguration new)! !

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 12:43'!
adminPassword
	^ 'setup'! !

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:57'!
errorHandler
	^ WAWalkbackErrorHandler ! !

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'avi 2/6/2004 17:57'!
mainClass
	^ SLBlogMain! !

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 12:43'!
adminUser
	^ 'admin'! !

!SLConfiguration methodsFor: 'as yet unclassified' stamp: 'avi 2/29/2004 13:06'!
attributes
	^ Array 
		with: (WAStringAttribute key: #adminUser group: #authentication)
		with: (WAStringAttribute key: #adminPassword group: #authentication)! !

!SLConfiguration class methodsFor: 'as yet unclassified' stamp: 'cwp 3/26/2004 21:46'!
initialize! !

!XMLElement class methodsFor: '*smallblog-override' stamp: 'avi 2/29/2004 12:08'!
named: aString
	^self named: aString attributes: Dictionary new! !
SLBlogStore initialize!
SLConfiguration initialize!
